---
name: User interface
about: Issues related to the User Interface of ASReview
title: ""
labels: front-end
assignees: J535D165, mmeijer23
---

**Describe the bug**
A clear and concise description of what the bug with the front-end is.
_What happened? And what did you expect to happen?_

**To Reproduce**
Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Version information**

- OS: [e.g. Windows]
- Browser [e.g. chrome, safari]
- ASReview version [e.g. 0.6.2]

**Additional context**
Add any other context about the problem here.
